# Caqtus

[![PyPI](https://img.shields.io/pypi/v/caqtus-suite)](https://pypi.org/project/caqtus-suite/)
[![doc](https://readthedocs.org/projects/docs/badge/?version=latest)](https://caqtus.readthedocs.io)

The `caqtus` package can be used to run precisely timed cold atom experiments.

<img src="doc/source/_static/screenshot.png" width="960" alt="Screenshot of the GUI">

The graphical interface is based on the table format used for example for the [Cicero Word Generator](https://github.com/akeshet/Cicero-Word-Generator).

However, the architecture and modularity are similar from the [Labscript Suite](https://github.com/labscript-suite).

## Installation

```bash
pip install caqtus-suite
```

## Configuration

*TODO*
